Name:          rtkit
Version:       0.13
Release:       %mkrel 2
Summary:       Realtime Policy and Watchdog Daemon
Group:         System/Libraries
License:       GPLv3+ and BSD
URL:           https://github.com/heftig/rtkit
Source0:       https://github.com/heftig/rtkit/releases/download/v%{version}/%{name}-%{version}.tar.xz
Patch1:        0001-Install-rtkitctl-to-sbin.patch
Patch2:        0002-Fix-rt-library-dependency.patch
Patch3:        0003-meson-use-option-systemd_systemunitdir.patch
BuildRequires: pkgconfig(dbus-1)
BuildRequires: pkgconfig(libcap)
BuildRequires: pkgconfig(polkit-agent-1)
BuildRequires: systemd-units
BuildRequires: meson
# for /usr/bin/xxd
BuildRequires: vim-common
Requires:      polkit >= 0.93
Requires(post):  rpm-helper >= 0.24.8-1
Requires(preun): rpm-helper >= 0.24.8-1

%description
RealtimeKit is a D-Bus system service that changes the
scheduling policy of user processes/threads to SCHED_RR (i.e. realtime
scheduling mode) on request. It is intended to be used as a secure
mechanism to allow real-time scheduling to be used by normal user
processes.

%prep
%setup -q
%autopatch -p1

%build
%meson -Dsystemd_systemunitdir=%{_unitdir}
%meson_build

./build/rtkit-daemon --introspect > org.freedesktop.RealtimeKit1.xml

%install
%meson_install

%post
%systemd_post rtkit-daemon.service
dbus-send --system --type=method_call --dest=org.freedesktop.DBus / org.freedesktop.DBus.ReloadConfig >/dev/null 2>&1 || :

%pre
%_pre_useradd rtkit /proc /sbin/nologin

%preun
%systemd_preun rtkit-daemon.service

%postun
%systemd_postun rtkit-daemon.service
%_postun_userdel rtkit

%files
%doc README rtkit.c rtkit.h
%attr(0755,root,root) %{_sbindir}/rtkitctl
%attr(0755,root,root) %{_libexecdir}/rtkit-daemon
%{_libexecdir}/installed-tests/rtkit/
%{_datadir}/dbus-1/system-services/org.freedesktop.RealtimeKit1.service
%{_datadir}/dbus-1/interfaces/org.freedesktop.RealtimeKit1.xml
%{_datadir}/polkit-1/actions/org.freedesktop.RealtimeKit1.policy
%{_mandir}/man*/rtkitctl.*
%{_datadir}/dbus-1/system.d/org.freedesktop.RealtimeKit1.conf
%{_unitdir}/rtkit-daemon.service


%changelog
* Tue Mar 29 2022 umeabot <umeabot> 0.13-2.mga9
+ Revision: 1832079
- Mageia 9 Mass Rebuild

* Mon Aug 31 2020 daviddavid <daviddavid> 0.13-1.mga8
+ Revision: 1620321
- new version: 0.13
- update Url and Source Url
- switch to meson build system

* Thu Apr 16 2020 pterjan <pterjan> 0.11-16.mga8
+ Revision: 1567922
- Fix usage of systemd_postun

* Fri Feb 14 2020 umeabot <umeabot> 0.11-15.mga8
+ Revision: 1516637
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Sun Sep 23 2018 umeabot <umeabot> 0.11-14.mga7
+ Revision: 1300863
- Mageia 7 Mass Rebuild

* Sat May 05 2018 wally <wally> 0.11-13.mga7
+ Revision: 1226241
- redo format-security patch to properly fix the issue

* Thu May 03 2018 daviddavid <daviddavid> 0.11-12.mga7
+ Revision: 1225505
- temporarily disable -Werror=format-security to unbreak the build

* Fri May 13 2016 tv <tv> 0.11-11.mga6
+ Revision: 1015031
- patch needs autoreconf
- use FC patch for linking issue
- fix doble %%postun
- use std systemd macros
- make dbus interface file non-executable (rhbz#1245938)
- use std build macro

* Mon Feb 08 2016 umeabot <umeabot> 0.11-9.mga6
+ Revision: 950473
- Mageia 6 Mass Rebuild

* Tue Nov 04 2014 colin <colin> 0.11-8.mga5
+ Revision: 795587
- Fix systemd unit file warnings (sadly rtkit is a bit broken generally for now tho')

* Wed Oct 15 2014 umeabot <umeabot> 0.11-7.mga5
+ Revision: 742974
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0.11-6.mga5
+ Revision: 688732
- Mageia 5 Mass Rebuild

* Sat Oct 19 2013 umeabot <umeabot> 0.11-5.mga4
+ Revision: 536088
- Mageia 4 Mass Rebuild

* Sun Sep 22 2013 colin <colin> 0.11-4.mga4
+ Revision: 483252
- Make polkit usage secure (mga#11260 CVE-2013-4326)

* Mon Jan 14 2013 luigiwalser <luigiwalser> 0.11-3.mga3
+ Revision: 381207
- explicitly link rt library to fix compilation error
+ umeabot <umeabot>
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Mon May 28 2012 colin <colin> 0.11-1.mga3
+ Revision: 248477
- New version: 0.11

* Sat Apr 28 2012 colin <colin> 0.10-3.mga2
+ Revision: 234092
- Ensure we build the systemd unit
- Enable systemd units.
+ tmb <tmb>
- Require rpm-helper >= 0.24.8-1 for systemd support

* Sun Jun 19 2011 kharec <kharec> 0.10-1.mga2
+ Revision: 109770
- fix file list
- new version 0.10

* Thu Jan 13 2011 colin <colin> 0.8-1.mga1
+ Revision: 16452
- imported package rtkit


* Tue Jul 13 2010 Colin Guthrie <cguthrie@mandriva.org> 0.8-1mdv2011.0
+ Revision: 552108
- New version: 0.8

* Sat May 08 2010 Colin Guthrie <cguthrie@mandriva.org> 0.7-1mdv2010.1
+ Revision: 543610
- New version: 0.7

* Sun Mar 07 2010 Sandro Cazzaniga <kharec@mandriva.org> 0.6-1mdv2010.1
+ Revision: 515357
- Update to 0.6

* Wed Dec 30 2009 Frederik Himpe <fhimpe@mandriva.org> 0.5-1mdv2010.1
+ Revision: 484077
- update to new version 0.5

* Wed Aug 05 2009 Colin Guthrie <cguthrie@mandriva.org> 0.4-1mdv2010.0
+ Revision: 410012
- New version: 0.4

* Wed Jul 29 2009 Frederic Crozat <fcrozat@mandriva.com> 0.3-2mdv2010.0
+ Revision: 403990
- Fix incorrect dependency on old policykit version
- Do not call autoreconf, not needed

* Thu Jul 02 2009 Colin Guthrie <cguthrie@mandriva.org> 0.3-1mdv2010.0
+ Revision: 391822
- New version 0.3
- Drop unneeded patches

* Wed Jun 24 2009 Colin Guthrie <cguthrie@mandriva.org> 0.2-1mdv2010.0
+ Revision: 388804
- import rtkit


